==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AccumulationDistributionIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AccumulationDistributionIndicatorDescription } from "./AccumulationDistributionIndicatorDescription";
/**
 * @hidden
 */
var AccumulationDistributionIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicatorDescriptionMetadata, _super);
    function AccumulationDistributionIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicatorDescriptionMetadata.b = function (a) {
        if (AccumulationDistributionIndicatorDescriptionMetadata.a == null) {
            AccumulationDistributionIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AccumulationDistributionIndicatorDescriptionMetadata.c(AccumulationDistributionIndicatorDescriptionMetadata.a);
        }
        if (a.g(AccumulationDistributionIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(AccumulationDistributionIndicatorDescriptionMetadata.a);
    };
    AccumulationDistributionIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    AccumulationDistributionIndicatorDescriptionMetadata.d = function (a) {
        AccumulationDistributionIndicatorDescriptionMetadata.b(a);
        a.u("AccumulationDistributionIndicator", function () { return new AccumulationDistributionIndicatorDescription(); });
        a.t("AccumulationDistributionIndicator", AccumulationDistributionIndicatorDescriptionMetadata.a);
    };
    AccumulationDistributionIndicatorDescriptionMetadata.$t = markType(AccumulationDistributionIndicatorDescriptionMetadata, 'AccumulationDistributionIndicatorDescriptionMetadata');
    AccumulationDistributionIndicatorDescriptionMetadata.a = null;
    return AccumulationDistributionIndicatorDescriptionMetadata;
}(Base));
export { AccumulationDistributionIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AccumulationDistributionIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AccumulationDistributionIndicatorDescription } from "./AccumulationDistributionIndicatorDescription";
/**
 * @hidden
 */
var AccumulationDistributionIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicatorDescriptionMetadata, _super);
    function AccumulationDistributionIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicatorDescriptionMetadata.b = function (a) {
        if (AccumulationDistributionIndicatorDescriptionMetadata.a == null) {
            AccumulationDistributionIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AccumulationDistributionIndicatorDescriptionMetadata.c(AccumulationDistributionIndicatorDescriptionMetadata.a);
        }
        if (a.j(AccumulationDistributionIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(AccumulationDistributionIndicatorDescriptionMetadata.a);
    };
    AccumulationDistributionIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    AccumulationDistributionIndicatorDescriptionMetadata.d = function (a) {
        AccumulationDistributionIndicatorDescriptionMetadata.b(a);
        a.aa("AccumulationDistributionIndicator", function () { return new AccumulationDistributionIndicatorDescription(); });
        a.z("AccumulationDistributionIndicator", AccumulationDistributionIndicatorDescriptionMetadata.a);
    };
    AccumulationDistributionIndicatorDescriptionMetadata.$t = markType(AccumulationDistributionIndicatorDescriptionMetadata, 'AccumulationDistributionIndicatorDescriptionMetadata');
    AccumulationDistributionIndicatorDescriptionMetadata.a = null;
    return AccumulationDistributionIndicatorDescriptionMetadata;
}(Base));
export { AccumulationDistributionIndicatorDescriptionMetadata };
